#iktomi

[![Build Status](https://travis-ci.org/SmartTeleMax/iktomi.svg?branch=master)](https://travis-ci.org/SmartTeleMax/iktomi)

Iktomi is a python package providing some basic tools for creating web applications. Iktomi is built on top of webob and supports Python 2.7 and Python3.5.

http://iktomi.readthedocs.org/
